@@ -1,7 +1,7 @@
 package Log::ger::Plugin::LogAny;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-07-12'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -55,27 +55,14 @@ Log::ger::Plugin::LogAny - Plugin to mimic Log::Any
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
- use Log::ger::Plugin 'LogAny';
- use Log::ger;
-
- log_warn "blah ...";
+Use from L<Log::ger::Like::LogAny>.
 
 =head1 DESCRIPTION
 
-This plugin does the following:
-
-=over
-
-=item * create log methods like Log::Any
-
-In addition to debug(), trace(), etc al also create debugf(), tracef(), et al.
-
-=back
-
 =for Pod::Coverage ^(.+)$
 
 =head1 SEE ALSO
